Pyrone markup language for writing articles

You can use Markdown in the comment body. Some most often used Markdown construction below.

Use empty line to split text into paragraphs. | ⇒ | Use empty line to split text into paragraphs.

You can also insert [hyperlinks](http://example.com). | ⇒ | You can also insert hyperlinks.

> this is a citing > (html element blockquote is being used for rendering) this element. Beginning characted “>” is required in the first line of citation block. | ⇒ | this is a citing (html element blockquote is being used for rendering) this element. Beginning characted “>” is required in the first line of citation block.